==> ?url=gopher%3A%2F%2Fdownloads.tuxfamily.org%3A70%2F9%2Fapertiumtrad%2Fapertiumtrad-local-1.2.tar: tradlemme.php <==
<?php
    // fonctions d'affichage de portions de pages HTML
    require ("acces_page.php");

    // fonctions de génération des menus déroulants
    require ("menus_deroulants.php");

    // fonction de traduction d'un lemme
    require ("gen_tradlemme.php");


    // Constantes
    require ("dirsite.php");
    define ('PAGE', "tradlemme");


    // sélectionner la langue de l'interface utilisateur
    $lg_util = choix_langue ();

    // traitement de la page de traduction d'un lemme
    $ficpage = DIRPAGE_ML."/".PAGE.".html";

    // si la page cherchée n'existe pas
    if (! file_exists ($ficpage))
    {
        // erreur fatale
        echo msg_chaine ("MANQUE_PAGE", PAGE);
        return;
    }

    // ouvrir le ficher contenant la page à afficher
    $descfic = fopen ($ficpage, "r");

    // si ouverture réussie
    if ($descfic)
    {
        // copier le début de la page en le corrigeant
        cop_debpage ($descfic);

        // copier jusqu'au champ caché srcprec et l'initialiser
        copmaj ($descfic, "XXXSRCPREC", $_POST ['langue_source']);

        // recopie jusqu'à la liste des langues sources
        copie_jusque_option ($descfic);

        // générer le menu déroulant des langues sources
        gen_langues_dispo ($_POST ['langue_source'], "l", $lg_util);

        // recopie jusqu'à la liste des langues cibles
        copie_jusque_option ($descfic);

        // si langue source choisie
        if (isset ($_POST ['langue_source']) && $_POST ['langue_source'] != "")
        {
            // générer le menu déroulant avec les langues
            // cibles disponibles pour une traduction directe
            gen_lg_cible_traddir ($_POST ['langue_source'],
                                  $_POST ['langue_cible'], "l", $lg_util);
        }
        // sinon laisser le champ vide

        // récupérer le lemme en remplaçant les ~u par ŭ pour l'esperanto
        $lemme = str_replace ("~u", "ŭ", $_POST ['lemme']);

        // copier jusqu'à la zone de saisie du lemme qui est remplacé par sa valeur
        copmaj ($descfic, "XXXLEMME", $lemme);

        // copier jusqu'à la zone d'affichage du résultat de la traduction
        copie_jusque_chaine ($descfic, "XXXRESULT");

        // si appui sur le bouton "Traduire"
        if (isset ($_POST ['traduction']))
            // générer le résultat de la traduction
            gen_tradlemme ($_POST ['langue_source'],
                           $_POST ['langue_cible'], $lemme, $lg_util);

        // terminer la page HTML
        copie_jusque_fin ($descfic);

        // page recopiée, on n'a plus besoin du fichier html
        fclose ($descfic);
    }
?>

==> ?url=gopher%3A%2F%2Fdownloads.tuxfamily.org%3A70%2F9%2Fapertiumtrad%2Fapertiumtrad-local-1.2.1.tar: tradlemme.php <==
<?php
    // fonctions d'affichage de portions de pages HTML
    require ("acces_page.php");

    // fonctions de génération des menus déroulants
    require ("menus_deroulants.php");

    // fonction de traduction d'un lemme
    require ("gen_tradlemme.php");


    // Constantes
    require ("dirsite.php");
    define ('PAGE', "tradlemme");


    // sélectionner la langue de l'interface utilisateur
    $lg_util = choix_langue ();

    // traitement de la page de traduction d'un lemme
    $ficpage = DIRPAGE_ML."/".PAGE.".html";

    // si la page cherchée n'existe pas
    if (! file_exists ($ficpage))
    {
        // erreur fatale
        echo msg_chaine ("MANQUE_PAGE", PAGE);
        return;
    }

    // si permutation des langues
    if (isset ($_POST ['permute']))
    {
        // le faire
        $lg_source = $_POST ['langue_cible'];
        $lg_cible  = $_POST ['langue_source'];
    }
    // sinon
    else
    {
        // récupérer les langues sélectionnées
        $lg_source = $_POST ['langue_source'];
        $lg_cible  = $_POST ['langue_cible'];
    }
    
    // ouvrir le ficher contenant la page à afficher
    $descfic = fopen ($ficpage, "r");

    // si ouverture réussie
    if ($descfic)
    {
        // copier le début de la page en le corrigeant
        cop_debpage ($descfic);

        // copier jusqu'au champ caché srcprec et l'initialiser
        copmaj ($descfic, "XXXSRCPREC", $lg_source);

        // recopie jusqu'à la liste des langues sources
        copie_jusque_option ($descfic);

        // générer le menu déroulant des langues sources
        gen_langues_dispo ($lg_source, "l", $lg_util);

        // recopie jusqu'à la liste des langues cibles
        copie_jusque_option ($descfic);

        // si langue source choisie
        if (isset ($lg_source) && $lg_source != "")
        {
            // générer le menu déroulant avec les langues
            // cibles disponibles pour une traduction directe
            gen_lg_cible_traddir ($lg_source,
                                  $lg_cible, "l", $lg_util);
        }
        // sinon laisser le champ vide

        // récupérer le lemme en remplaçant les ~u par ŭ pour l'esperanto
        $lemme = str_replace ("~u", "ŭ", $_POST ['lemme']);

        // copier jusqu'à la zone de saisie du lemme qui est remplacé par sa valeur
        copmaj ($descfic, "XXXLEMME", $lemme);

        // copier jusqu'à la zone d'affichage du résultat de la traduction
        copie_jusque_chaine ($descfic, "XXXRESULT");

        // si appui sur le bouton "Traduire"
        if (isset ($_POST ['traduction']))
            // générer le résultat de la traduction
            gen_tradlemme ($lg_source,
                           $lg_cible, $lemme, $lg_util);

        // terminer la page HTML
        copie_jusque_fin ($descfic);

        // page recopiée, on n'a plus besoin du fichier html
        fclose ($descfic);
    }
?>
